#
# spec file for package movit
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _sonum  8
Name:           movit
Version:        1.7.1
Release:        bp156.1.4
Summary:        GPU video filter library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://movit.sesse.net
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(eigen3) >= 3.4.0
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(sdl2)
%if 0%{?suse_version} == 1315
# For SLE12
BuildRequires:  gcc7-c++
%else
BuildRequires:  gcc-c++
%endif

%description
Movit is a library for video filters. It uses the GPU present in many
computers to accelerate computation of common filters and
transitions, facilitating real-time HD video editing.

%package -n libmovit%{_sonum}
Summary:        GPU video filter library
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
# Shaders used to be split; Ensure upgrade path until Leap 15.5 EOL (Dec. 2024).
Provides:       %{name}%{_sonum}-data = %{version}
Obsoletes:      %{name}%{_sonum}-data < %{version}

%description -n libmovit%{_sonum}
Movit is a library for video filters. It uses the GPU present in many
computers to accelerate computation of common filters and
transitions, facilitating real-time HD video editing.

This package contains the Movit shared library.

%package        devel
Summary:        Development files for the Movit GPU video filter library
Group:          Development/Libraries/C and C++
Requires:       libmovit%{_sonum} = %{version}

%description    devel
Movit is a library for video filters. It uses the GPU present in many
computers to accelerate computation of common filters and
transitions, facilitating real-time HD video editing.

This package contains the development files (library and header files).

%prep
%setup -q

%build
# For SLE12, force use of GCC 7
test -x "$(type -p gcc-7)" && export CC=gcc-7
test -x "$(type -p g++-7)" && export CXX=g++-7

./autogen.sh
%configure --disable-static

make %{?_smp_mflags} TESTS=

%install
%make_install
rm %{buildroot}%{_libdir}/libmovit.la

%post -n libmovit%{_sonum} -p /sbin/ldconfig
%postun -n libmovit%{_sonum} -p /sbin/ldconfig

%files -n libmovit%{_sonum}
%license COPYING
%doc README NEWS
%{_libdir}/libmovit.so.*

%files devel
%license COPYING
%{_libdir}/libmovit.so
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sat Jul 22 2023 antoine.belvire@opensuse.org
- Update to version 1.7.1: Fix a bug when compiling in shaders,
  that could cause errors with certain shader compilers.
* Sat Jul 15 2023 antoine.belvire@opensuse.org
- Update to version 1.7.0:
  * Compile shaders into the library.
  * Use exact sRGB matrix values for COLORSPACE_sRGB.
- Drop movit-1.6.0-versioned-shaderdir.patch: Made irrelevant
  since shaders are now compiled into the library.
- Specify a minimal version for Eigen3: Build now fails with a
  version below 3.4.0.
* Sun Jul  7 2019 antoine.belvire@opensuse.org
- Update to version 1.6.3:
  * Various bugfixes.
- Add _service file to retrieve sources as published tarball lacks
  some files (e.g. COPYING).
* Sun Mar 18 2018 avindra@opensuse.org
- Update to version 1.6.2:
  * fix issue with strong one-to-one effects and compute shaders
  * fix compile issue with gcc5
- cleanup with spec-cleaner
* Sun Feb  4 2018 jengelh@inai.de
- Fix the shlib package's RPM group.
* Sat Feb  3 2018 antoine.belvire@opensuse.org
- Update to version 1.6.1:
  * Loosen up some restrictions on strong one-to-one-effects. In
    particular, this fixes a bug with MixEffect and compute shaders
    that hit some Nageru setups.
* Sat Jan 27 2018 antoine.belvire@opensuse.org
- Fix build for Leap 42.3: Force use of GCC7.
* Thu Jan 25 2018 antoine.belvire@opensuse.org
- Update to version 1.6.0:
  * Support for effects that work as compute shaders. Compute
    shaders are generally slower than fragment shaders for the same
    algorithm, but allow some forms of communication between shader
    invocations and have more flexible output, which can enable
    more efficient algorithms. See effect.h for more details. Note
    that the fastest rendering API on EffectChain is now to a
    texture if possible, not to an FBO. This will only matter if
    the last effect is a compute shader.
  * Movit now includes a compute shader implementation of
    DeinterlaceEffect, which is automatically used instead of the
    fragment shader implementation if your GPU and OpenGL driver
    supports it (in practice, this means on all platforms except on
    macOS). The compute shader version is typically 20–80%% faster
    than the fragment shader version, depending on your GPU and
    other factors.
    A compute shader implementation of ResampleEffect was written but
    ultimately failed to be faster, and so is not included.
  * Support for microbenchmarks of effects through the Google
    microbenchmarking framework (optional). Currently,
    DeinterlaceEffect and ResampleEffect has benchmarks; enable
    them by running the unit test with --benchmark (also try
  - -benchmark --help).
  * Effects can now explicitly request _not_ to have mipmaps, which
    means they can do so without needing to request bounce and
    fiddling with the sampler state. Note that this is an API
    change for effects.
  * Movit now requires C++11, both to build and to #include the
    header files. Support for SDL1 has been dropped; unit tests and
    the demo program now need SDL2.
  * Various smaller bugfixes and optimizations.
- Drop COPYING (now included in upstream tarball).
- Now build requires SDL2 instead of SDL1.
- (Experiment) Make data subpackage versioned, as the library is
  versioned and requires the data files:
  * Add movit-1.6.0-versioned-shaderdir.patch.
- Ran spec-cleaner.
* Fri Aug 11 2017 antoine.belvire@opensuse.org
- Update to 1.5.3:
  * Various bugfixes.
- Don't use gcc6-c++ for Leap anymore: It builds fine with default
  compiler again.
* Tue Jul 11 2017 olaf@aepfle.de
- Use gcc6-c++ for Leap42 and SLE12 (C++14 needed).
* Mon Jul 10 2017 antoine.belvire@opensuse.org
- Update to 1.5.2:
  * The texture generation for ResampleEffect (when the size is
    changed) now uses less CPU.
  * Work around an NVIDIA driver threading bug by aggressively
    caching VAOs.
  * Update soname to libmovit.so.7.
- Remove call to autogen.sh as we don't patch Makefile.in anymore.
* Sun Jun  4 2017 antoine.belvire@opensuse.org
- Update to 1.5.1:
  * Allow YCbCrInput to change input format after finalize.
  * Some minor YCbCrInput bugfixes.
* Sun Mar 26 2017 antoine.belvire@opensuse.org
- Update to 1.5.0:
  * Support interleaved Y'CbCr input (4:4:4 in a single texture).
  * Support 10-bit and 12-bit Y'CbCr, both for input and output.
  * Limited support for having multiple Y'CbCr outputs from a
    chain.
  * Allow changing the Y'CbCr output coefficients runtime, i.e.
    after finalize.
  * Fix an issue where the last pass would have been rendered with
    the sRGB flag set, which confused Qt applications running in
    certain NVIDIA configurations.
* Fri Mar  3 2017 olaf@aepfle.de
- Remove googletest dependency because tests can not be run without
  an X display
- Drop movit-1.2.0-use-gtest-shared-library.patch
* Sat Dec 17 2016 antoine.belvire@opensuse.org
- Update to 1.4.0:
  * Allow setting the intermediate format for chains, instead of
    hardcoding it at 16-bit RGBA; advanced users can use this to
    e.g. ask for 8-bit sRGB intermediates, reducing the amount of
    memory bandwidth needed at the cost of reduced precision.
    Whether this is a good tradeoff or not depends on the exact
    chain and your requirements.
  * Fix an issue where a (cached) shader program could be used
    from multiple threads at a time, causing the uniforms to
    contain unpredictable values.
  * Make the error printed on check_error() slightly friendlier:
    Include the enum if possible, and print it to stderr instead
    of stdout.
* Sun Oct 16 2016 jengelh@inai.de
- Trim filler words from descriptions
* Tue Oct 11 2016 toddrme2178@gmail.com
- Update year
- Fix version testing ("=" instead of "==")
- Delete unneeded files instead of excluding.
- Split data files into their own subpackage.
* Sun Oct  9 2016 antoine.belvire@opensuse.org
- Add and install missing license file (COPYING, it's the GPLv3)
- Install changelog file (NEWS)
* Sat Mar  5 2016 antoine.belvire@opensuse.org
- Update to 1.3.2:
  * Fix several bugs
* Tue Feb  9 2016 antoine.belvire@opensuse.org
- Update to 1.3.0:
  * Fix several bugs
  * Add a deinterlacer based on YADIF
  * Add new GLSL 1.50 shaders
  * Remove support for GLSL 1.10
- Use the official tarball as source
* Mon Dec 21 2015 antoine.belvire@opensuse.org
- Initial package: movit-1.2.0
